Diagnose add_person function and permissions
diagnose_add_person_setup.RdDiagnostic tool to check if the secure add_person() function is properly set up and accessible by the current user.

diagnose_add_person_setup.RdDiagnostic tool to check if the secure add_person() function is properly set up and accessible by the current user.