Diagnose plot insertion permissions
diagnose_plot_permissions.RdDiagnostic tool to check if a user has the necessary permissions to insert plots into data_liste_plots and related tables.

diagnose_plot_permissions.RdDiagnostic tool to check if a user has the necessary permissions to insert plots into data_liste_plots and related tables.