Skip to contents

Named character vector mapping the specimen columns that update_specimen_fields is allowed to write to their expected R type ("character", "numeric" or "integer").

Identification fields (idtax_n, detby, detd, detm, dety, detvalue) are deliberately excluded: they are handled by update_ident_specimens.

Usage

.specimen_editable_fields()

Value

Named character vector, names are specimen column names.