Get backbone cache directory path
get_backbone_cache_path.RdReturns the path to the cache directory for taxonomic backbone storage. Creates the directory if it doesn't exist. Uses platform-appropriate cache location via `tools::R_user_dir()`.

get_backbone_cache_path.RdReturns the path to the cache directory for taxonomic backbone storage. Creates the directory if it doesn't exist. Uses platform-appropriate cache location via `tools::R_user_dir()`.