Skip to contents

Creates log_dir if needed and writes header rows to connections_log.csv and stats_log.csv when the files do not yet exist.

Usage

init_activity_log(log_dir)

Arguments

log_dir

Path to the directory that will hold the log files.

Value

log_dir invisibly.