Create user registry table
create_user_registry.RdCreates the `user_registry` table in the main database to store user metadata (email, institution, etc.). This table is used for user tracking and communication, not for authentication.
**For database administrators only.**
Examples
if (FALSE) { # \dontrun{
con <- call.mydb()
create_user_registry(con)
} # }